{%- block header -%}{%- endblock -%}
{{ title }}

{{ body }}
{%- block inset -%}{%- endblock -%}
# Please enter the content for your new bug, the first line will be used for
# the title.  Lines beginning with '#' will be ignored
{%- block footer -%}{%- endblock -%}
